.. =================
.. PyLadies Handbook
.. =================

.. So You’ve Decided to Start Your Own PyLadies Chapter
.. ----------------------------------------------------

.. YAY! We’re excited to have people like you join our growing community
.. and want to help you get your chapter launched as quickly and painlessly
.. as possible. If our experience is any indication, your first major event
.. will galvanize and inspire the Python community in your area and create
.. momentum for subsequent events, so it’s crucial to start things off on
.. the right foot!

.. To help you get started, we’ve created an open-source kit for starting
.. your own PyLadies chapter in your city. PyLadies is part social club,
.. part stepping stone toward the Python open-source world.

.. What you need
.. -------------

.. You may of course adapt this list to meet your chapter’s needs.

.. Organizers
.. ~~~~~~~~~~

.. 2-10 Python lady developers who want to be local PyLadies chapter
.. organizers

.. Promotion and Outreach
.. ~~~~~~~~~~~~~~~~~~~~~~

.. Various local channels for promoting your group, including meetup.com,
.. local PUGs, related groups, and universities. Also, a list of global
.. PyLadies channels that you can use.

.. Events
.. ~~~~~~

.. At minimum, try to hold one event a month -- this helps keep interest in
.. PyLadies from flagging, and helps people maintain their progress in
.. becoming better developers. You can hold more events with proper support
.. and planning.

.. How to use this kit
.. -------------------

.. Copy our model (fork & contribute). Or fork and make it completely
.. different. We don’t mind if you get creative!

.. About PyLadies Chapters
.. -----------------------

.. Types of Chapters
.. ~~~~~~~~~~~~~~~~~

.. A chapter can be:

.. #. a geographic chapter: for a city, region, state, or country
.. #. a student chapter: for a university, college, or school
.. #. an interest group chapter: for any topic (e.g. PyGame, SciPy, Django)

.. The larger the chapter, the harder it is to meet in person. Large
.. chapters’ events will be mostly virtual meetups that occur online,
.. whereas small chapters’ events tend to be in-person meetups.

.. A chapter can consist of sub-chapters, making both the in-person and
.. virtual meetups possible.

.. Chapter Size
.. ~~~~~~~~~~~~

.. It’s fine if your chapter is small. Having just 2-3 women who meet
.. regularly to exchange Python tips and tricks counts as a chapter. What matters
.. most is quality, not quantity.

.. Larger chapters have more flexibility to organize different types of
.. events, but it’s harder to get everyone together for dinner.

.. Initial setup of your chapter
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. Email info@pyladies.com with the following info:

.. #. Names/emails of co-organizers.
.. #. Desired subdomain for your chapter
..    (http://your-subdomain.pyladies.com). This can be geographic,
..    university/school-related, interest group-related, or almost any
..    other name of your choice.
.. #. 1-2 paragraph blurb about your chapter so we can announce it on
..    `pyladies.com/blog <http://pyladies.com/blog>`_ and in the PyLadies
..    global newsletter.
.. #. Desired email address (whatever@pyladies.com).

.. Create at least one of the following:

.. #. a group on Meetup.com for your chapter (recommended; ask us about
..    sponsorship if you need help with the Meetup subscription fees)
.. #. a website and mailing list for your chapter (note: Meetup.com has
..    this built in; consider using that to simplify things)

.. Post a description of your first event on your Meetup.com group or
.. website. It can be as simple as “We’re getting together at X Coffee
.. Shop, 123 Main St., Anytown to make plans for our new PyLadies chapter.
.. All local Python developer women (and their +1 guests) (and men
.. interested in helping out) are invited.”

.. Then see the Promotion section of the PyLadies Handbook for info about
.. how to promote your first chapter event!

.. Events
.. ------

.. Organizer Events
.. ~~~~~~~~~~~~~~~~

.. Very useful for planning sessions, but also for support and
.. accountability.

.. Python Ladies' Nights
.. ~~~~~~~~~~~~~~~~~~~~~

.. The PyLadies aren’t ALL about coding -- we also love to socialize and
.. have fun!

.. Hosted: a potluck/party at a member’s house

.. Meet: at a bar or restaurant

.. Workshops
.. ~~~~~~~~~

.. You can host workshops either as full-day events every 1-3 months or so,
.. or as evening events that occur weekly.

.. Intro to Python
.. ^^^^^^^^^^^^^^^

.. #. Austin PyLadies `Intro to Python <https://github.com/pyladiesatx/pyladiesatx/tree/master/classes/python_intro>`
.. #. PyStar has some great tutorials for beginners.
.. #. Learn Python the Hard Way by Zed Shaw
.. #. custom (depending on your needs)

.. Intro to Django
.. ^^^^^^^^^^^^^^^

.. #. Poll tutorial from
..    `docs.djangoproject.com <http://docs.djangoproject.com>`_
.. #. Sandy Strong's `Intro to Django Workshop slides <http://bit.ly/qMcEAT>`_

.. Other topic of interest workshop
.. ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. #. Find a programming/relevant developer book that you’d like to study.
..    Host a weekly study group.
.. #. Host a weekend workshop about game programming, startups, journalism,
..    etc.

.. Hackathons/Sprints
.. ~~~~~~~~~~~~~~~~~~

.. LA PyLadies has hosted hackathons where attendees bring laptops and
.. projects of their own to work on. Beginners are pointed to
.. `learnpythonthehardway.org <http://learnpythonthehardway.org>`_ and
.. instructed to work through the tutorial, asking for help as needed. They are
.. urged to post exercises to Github, as a way to dip their toes in the world
.. of open source sofware.

.. Hackathons can be evening, full-day, or all-weekend events.

.. Virtual meetups
.. ~~~~~~~~~~~~~~~

.. PyLadiesAU held their first chapter meeting as a virtual meetup. See
.. `http://au.pyladies.com/events/32589162/ <http://au.pyladies.com/events/32589162/>`_
.. for details.

.. The IRC #pyladies channel is always available for anyone to use for
.. virtual meetups. Feel free to use it without asking, or create a
.. #pyladies-whatever channel if you prefer.

.. Meetups as part of a Python user group (PUG) meetup
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. A PyLadies event can be as simple as women getting together and talking
.. about each others’ Python projects in a small group after a local PUG
.. event.

.. Anything to encourage women to attend and continue attending PUGs is
.. great. Talk to your local PUG organizers and ask for their help and
.. support in having a post-PUG informal PyLadies meetup.

.. You might also consider trying to give a :doc:`talks/beginner` at a 
.. meetup. This can help bring more beginners who might otherwise be 
.. scared away to the group.

.. Code review sessions
.. ~~~~~~~~~~~~~~~~~~~~

.. Reviewing someone’s coding project together can help everyone learn
.. better coding practices.

.. Conference prep sessions
.. ~~~~~~~~~~~~~~~~~~~~~~~~

.. Python conferences that might interest your chapter: PyCon, DjangoCon,
.. PloneConf, SciPy (Python for Scientific Computing)

.. What you can do to prepare together:

.. #. Brainstorm talk ideas. Help each other put together talk outlines.
.. #. Review each others’ talk proposals.
.. #. Practice talks in front of each other, in a small group.
.. #. Practice in a larger group, as a joint event with the local Python
..    user group.

.. Conferences can be stressful, but they’re also a lot of fun,
.. particularly if you’re attending with a friend or a small group. There's
.. also a good chance you will run into PyLadies from other chapters!

.. Promotion
.. ---------

.. One benefit of creating a PyLadies chapter is having access to a
.. worldwide support network of PyLadies who can help you spread word about
.. your events.

.. How to promote your events locally
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. Do the following:

.. #. Post an event description on your `meetup.com <http://meetup.com>`_
..    page or website.
.. #. Announce the event via your mailing list.
.. #. Create event flyers and distribute them at meetups, Python user group
..    meetings, work, and the local universities. See [upload example or
..    template to git repo] for an example.
.. #. Approach the career offices and engineering/science departments of
..    local colleges and universities.
.. #. Contact old professors and teachers. Tell them about what you’re
..    doing; they’ll be glad to hear from you. Ask to make an announcement
..    to their current students at the start of their classes, or as an
..    email.
.. #. Attend local tech/Python meetups. Be an active part of the local
..    developer community. Show that you care about getting more women into
..    Python development and programming in general. Be humble and ask for
..    help from the group.

.. How we can help
.. ~~~~~~~~~~~~~~~

.. Email the main point of contact for any of the following channels, and
.. provide text and/or images for us to use:

.. #. Global PyLadies Newsletter: Good for announcements about meetups.
..    Subscribers from all over the world. Please keep the text
..    brief and include an image. (info@pyladies.com)
.. #. PyLadies blog: we would love for you to contribute posts to our blog!
..    It's as simple as forking and then making a pull request off
..    http://github.com/pyladies/pyladies

.. In addition, promote all of your events directly through the following:
.. 6. PyLadies Google group: http://groups.google.com/group/pyladies
.. 7. #pyladies IRC channel (FreeNode)

.. Whenever you have news of interest to the PyLadies community, all the
.. above channels are available to help you make your announcement. We are
.. always looking for good quotes and photos from Python developer women.


.. Guidelines for using the PyLadies promotion channels
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. Anything of interest to women in the Python community can be posted in
.. the various PyLadies channels, provided that it meets these guidelines:

.. #. **Send us the actual text that you want posted.**
.. #. For local PyLadies chapter events:

..    * Send text for as many events as possible to the channels listed above.
..      The more we can promote your events, the better.
.. #. For non-chapter events and general postings:

..    * Postings should be relevant to women.  Mention the women organizing
..      and/or attending the event.  Have their names link to their websites or
..      Twitter accounts.
..    * Don't just reuse the same blurb that you use everywhere; customize it to
..      be relevant to the specific audience you're addressing.
..    * We'd love to use the various channels to feature what PyLadies from
..      everywhere are doing.  If you know of someone who should be featured,
..      you can write up something interesting for the blog, Twitter stream, etc.
..    * If you are hosting a Python community event or conference and need our
..      help getting more women to attend, submit proposals, etc., a heartfelt
..      explanation about why more women should attend and feel welcome goes a
..      long way. A PyLadies discount code also helps: keep in mind that a huge
..      part of our audience are students/those just starting out professionally
..      with Python, who cannot afford to commit to events or submit
..      proposals unless there is a known, guaranteed PyLadies discount.

.. Finding Sponsors/Raising Funds
.. ------------------------------

.. If your chapter is small, you don’t necessarily need sponsors. Hosting
.. chapter meetups at coffee shops, restaurants, or people’s houses is
.. fine.

.. However, you may want to organize trips, conferences, and other types of
.. more costly events. If so, you will need to raise local chapter funds
.. and ask local Python shops to consider sponsoring an event.

.. Venue Sponsors
.. ~~~~~~~~~~~~~~
.. Research local companies and approach them. Often, a company that
.. already hosts other meetups will be willing to host your PyLadies
.. chapter. Ask them if they’ll provide pizza/drinks; if not, charge
.. attendees a fee that covers food (and more, if you want to use the funds
.. for future events).

.. Fiscal Sponsorship from the PSF
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. The `Python Software Foundation <http://python.org/psf>`_ has been very supportive of PyLadies.
.. They have a `special donation page <https://psfmember.org/civicrm/contribute/transact?reset=1&id=6>`_,
.. where donors can use PayPal to make donations directly to the PSF that are
.. tax-deductible, which can then be used to reimburse PyLadies organizers who
.. pay for various event costs.


.. PSF Grant Programs
.. ~~~~~~~~~~~~~~~~~~

.. See our `sample PSF grant proposal to raise money for t-shirts, tables,
.. and chairs:
.. <https://github.com/pyladies/pyladies-kit/blob/master/grant-proposals/sample-hackathon.pdf?raw=true>`_

.. You can apply for a Python Sprints grant to raise money for food, power
.. strips, name tags, and anything else you might need to run a
.. sprint/hackathon, up to $300:


.. Selling t-shirts/merchandise
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. Some PyLadies designs and printing instructions are provided with this
.. kit. The cost is roughly $500-750 for 60 shirts. Shirts can be sold for
.. $20 each (you can adjust the price to meet your needs/currency, of
.. course).

.. See the “T-Shirts, Stickers, and Other Merchandise” section for more
.. details.

.. Corporate sponsorship
.. ~~~~~~~~~~~~~~~~~~~~~

.. Many companies are looking for ways to give back to the developer
.. community. You’ll want to put together a corporate sponsor info packet.

.. See our sample info packet at [upload sponsorship doc to git repo].
.. Borrow ideas from it, and customize it to fit your chapter.

.. Swag: T-Shirts, Stickers, and Other Merchandise
.. -----------------------------------------------

.. Currently, T-shirts are available via Spreadshirt at
.. `http://pyladies.spreadshirt.com/ <http://pyladies.spreadshirt.com/>`_.
.. Proceeds from the shop benefit the PyLadies organization and go toward
.. things like nonprofit corporation setup, helping new chapters, servers,
.. etc.

.. Sometimes we also create limited runs of T-shirts, stickers, etc. Check
.. the blog or ask around in IRC #pyladies if you’re interested in seeing
.. what we have.

.. Local chapter merchandise
.. ~~~~~~~~~~~~~~~~~~~~~~~~~

.. If you’d like to create merchandise for your own chapter, you can create
.. a shop on Spreadshirt, Zazzle, or any other print-on-demand site and
.. have the proceeds go toward your chapter.

.. Or you can have a local print shop print a small run.


.. IRC #pyladies Community
.. -----------------------

.. Whether or not you’re part of a local chapter, the IRC #pyladies
.. community welcomes you. #pyladies is on irc.freenode.net. Instructions
.. on how to chat in #pyladies IRC:
.. `http://pyladies.com/chat/ <http://pyladies.com/chat/>`_

.. Quite a few well-known men and women in the Python community participate
.. there and try to keep it a friendly place. Ask Python questions there,
.. talk about what your local chapter is up to, or just say hi.

.. Anyone can plan and host virtual meetups in IRC #pyladies. You should
.. host one! Just tell one of the ops to update the topic with info about
.. your meetup. See the “Promotion” section for further details about how
.. we can help spread word.

.. You can also create #pyladies-whatever IRC channels for your country,
.. language, interest group, etc. Ask sandpy for help registering your
.. channel under the #pyladies namespace.

PyLadies Google Group
---------------------

We also have a Google Group that anyone can use for random discussion.
This group is for women Python developers and gives all PyLadies a space
of our own to discuss things or post announcements.

We are looking for volunteers to start and lead discussions here.
Interested? No need to ask permission! Just take over (because that’s
what real Djangstas do ;) and we’ll gladly chime in on the discussion.

How to use it:

#. Subscribe at
   `http://groups.google.com/group/pyladies <http://groups.google.com/group/pyladies>`_
#. To post, email
   `pyladies@googlegroups.com <mailto:pyladies@googlegroups.com>`_. Add
   [PyLadies] as the subject of the email, to make it easier for
   subscribers to filter their PyLadies mail.

.. Points of Contact
.. -----------------

.. info@pyladies.com is the best place to shoot any questions you may have

.. If you have more casual questions, IRC is one of the best places to start.
.. You can usually find several of the main PyLadies points of contact in
.. #pyladies.

.. Policies
.. --------

.. We try not to have too many rules and regulations (everything above
.. has been nothing more than advice we offer to make things easier for
.. you, given that we learned much of it the hard way). Generally, chapter
.. organizers are free to do whatever they want, as long as it’s in the
.. best interest of their local chapter and/or PyLadies in general.

.. The following policies have been written up so that you may simply copy
.. and paste them into email responses, to help you deal with awkward or
.. tricky situations.

.. Official PyLadies Guest Policy
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. (If anyone asks to stay with you in the future other than a trusted
.. friend, say something like "I wish we could accommodate you, but
.. PyLadies has a strict policy of not allowing members to host out-of-town
.. guests" and then paste this, minus the parenthetical note.)

.. In the interest of safety and security of our members, PyLadies
.. organizers, volunteers, and members are not permitted to host overnight
.. out-of-town guests who wish to visit town for PyLadies events.

.. This is a strict formal policy, chosen to ensure that the PyLadies
.. organization continues to be taken seriously and treated with complete
.. respect by the professional software and tech communities.

.. Policy on Controversial Issues
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. As a PyLadies local chapter organizer, you may be asked for PyLadies’
.. position on controversial issues. Often, these are diversity-related
.. issues.

.. PyLadies’ policy is to have no official position on controversial
.. issues. By choosing this policy, we allow ourselves to be a group full
.. of diverse ideas and differing viewpoints.

.. Frequently Asked Questions
.. --------------------------

.. Can men attend local PyLadies chapter events?
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. It’s up to you. Generally, it’s good to hold women-only events as well
.. as events for both genders (either women and +1 guests, or anyone who
.. wants to attend). Just be aware that the dynamic of the room tends to
.. change when the male:female ratio becomes lopsided.

.. A good way to hold a mixed-gender event is to partner with a local
.. Python user group.

.. Be extra-clear in your event description about whether men are
.. allowed/what the rules are -- it will save you a lot of time, and
.. prevent awkward conversations.

.. Is there anything like PyLadies specifically for men?
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. There doesn’t seem to be a burning need for a PyLadies for Men ;) That
.. said, if you’re a man and want to start a similar group, we’ll support
.. you. You can even make PyLadies knock-off t-shirts. One enterprising
.. gent has printed “PyLaddies” shirts, and there is an IRC channel on
.. Freenode, #pygents, for the men who love PyLadies =)

.. Can I use the PyLadies logo and graphics for any purpose?
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. Any of the graphics at
.. `https://github.com/pyladies/pyladies-kit <https://github.com/pyladies/pyladies-kit>`_
.. can be used for your own chapter promotion. Feel free to use them for
.. websites, printed materials, t-shirts, and anything else that benefits
.. your chapter.

.. Even if you don’t have an official chapter, you can use the graphics for
.. anything women-in-Python related, as long as any funds resulting from
.. your use of the graphics go toward Python gender diversity initiatives.


.. Can transgender women be PyLadies?
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. Anyone who considers herself a lady and does Python is a PyLady/Python
.. lady. We support all women, whether female by birth or not.

.. We encourage you sure to make trans women feel welcome by saying so in your
.. meetup group and event descriptions. Here is an example of a statement you
.. could include:

..     PyLadies [city] is welcoming to and respectful of trans women. We
..     encourage all women to come out to our meetups.

.. If the idea of trans people is new to you, you might want to take a look at
.. `this fantastic illustrated book about gender <http://www.thegenderbook.com>`_,
.. `this comic <http://www.roostertailscomic.com/?p=1495>`_, or any of the
.. many other introductions to trans issues on the internet.

.. Is your goal to segregate by gender?
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. No! PyLadies and local PyLadies chapters are about making the Python
.. community explicitly welcoming and accessible to women.

.. Women who wouldn’t otherwise attend a Python user group meeting often
.. attend local PyLadies chapter events, as a gateway to getting involved
.. with Python programming as a beginner, or getting more involved in the
.. Python community as an intermediate/advanced developer.

.. What if my question isn’t answered here?
.. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. Ask in IRC #pyladies on `irc.freenode.net <http://irc.freenode.net>`_ if
.. you must. But feel free to organize your PyLadies chapter however you
.. wish, and make it completely your own. We’re here to help you, not to
.. limit you or control your plans.
